@@ -38,9 +38,9 @@ except ImportError:
 
 
 # Initialise the constants.
-PYQT_VERSION_STR = "4.10.2"
+PYQT_VERSION_STR = "4.10.3"
 
-SIP_MIN_VERSION = '4.14.3'
+SIP_MIN_VERSION = '4.15'
 
 
 class ModuleMetadata:
@@ -504,8 +504,9 @@ int main(int argc, char **argv)
     out << "PyQt_NoOpenGLES\\n";
 #endif
 
-    if (sizeof (qreal) != sizeof (double))
-        out << "PyQt_qreal_double\\n";
+#if defined(QT_NO_FPU) || defined(QT_ARCH_ARM) || defined(QT_ARCH_WINDOWSCE) || defined(QT_ARCH_SYMBIAN) || defined(QT_ARCH_VXWORKS)
+    out << "PyQt_qreal_double\\n";
+#endif
 
     return 0;
 }
@@ -520,7 +521,7 @@ int main(int argc, char **argv)
         run_command(cmd, verbose)
 
         if not os.access(out_file, os.F_OK):
-            error("%s failed to create %s. Make sure your Qt installation is correct." % (exe_file, out_file))
+            error("%s failed to create %s. Make sure your Qt installation is correct." % (cmd, out_file))
 
         # Read the details.
         f = open(out_file)
@@ -564,32 +565,38 @@ int main(int argc, char **argv)
         # Query qmake.
         qt_config = TargetQtConfiguration(self.qmake)
 
-        self.designer_plugin_dir = qt_config.QT_INSTALL_PLUGINS + '/designer'
-
         self.qt_version = 0
         for v in qt_config.QT_VERSION.split('.'):
             self.qt_version *= 256
             self.qt_version += int(v)
 
+        # Check the Qt version number as soon as possible.
+        if self.qt_version < 0x040100:
+            error("PyQt4 requires Qt v4.1.0 or later. You seem to be using v%s. Use the --qmake flag to specify the correct version of qmake." % version_to_string(self.qt_version))
+
+        self.designer_plugin_dir = qt_config.QT_INSTALL_PLUGINS + '/designer'
+
         # By default, install the API file if QScintilla seems to be installed
         # in the default location.
         self.qsci_api_dir = os.path.join(qt_config.QT_INSTALL_DATA, 'qsci')
         self.qsci_api = os.path.isdir(self.qsci_api_dir)
 
-        # The binary MacOS/X Qt installer defaults to XCode.  If this is what
-        # we might have then use macx-clang (Qt v5) or macx-g++ (Qt v4).
+        if opts.qmakespec is not None:
+            self.qmake_spec = opts.qmakespec
+
         if sys.platform == 'darwin':
-            try:
-                # Qt v5.
-                if qt_config.QMAKE_SPEC == 'macx-xcode':
-                    # This will exist (and we can't check anyway).
-                    self.qmake_spec = 'macx-clang'
-                else:
-                    # No need to explicitly name the default.
-                    self.qmake_spec = ''
-            except AttributeError:
-                # Qt v4.
-                self.qmake_spec = 'macx-g++'
+            if opts.qmakespec is None:
+                # The binary MacOS/X Qt installer defaults to XCode.  If this
+                # is what we might have then use macx-clang (Qt v5) or macx-g++
+                # (Qt v4).
+                try:
+                    # Qt v5.
+                    if qt_config.QMAKE_SPEC == 'macx-xcode':
+                        # This will exist (and we can't check anyway).
+                        self.qmake_spec = 'macx-clang'
+                except AttributeError:
+                    # Qt v4.
+                    self.qmake_spec = 'macx-g++'
 
             # See if it is a framework.
             if os.access(os.path.join(qt_config.QT_INSTALL_LIBS, 'QtCore.framework'), os.F_OK):
@@ -612,6 +619,9 @@ int main(int argc, char **argv)
         if opts.debug:
             self.debug = True
 
+        if opts.designerplugindir is not None:
+            self.designer_plugin_dir = opts.designerplugindir
+
         if opts.destdir is not None:
             self.module_dir = opts.destdir
 
@@ -627,9 +637,6 @@ int main(int argc, char **argv)
         if opts.nodocstrings:
             self.no_docstrings = True
 
-        if opts.plugindir is not None:
-            self.plugin_dir = opts.plugindir
-
         if opts.protispublic is not None:
             self.prot_is_public = opts.protispublic
 
@@ -863,9 +870,9 @@ def create_optparser(target_config):
             metavar="DIR",
             help="install the PyQt4 Python package in DIR [default: "
                     "%s]" % target_config.module_dir)
-    g.add_option("--designer-plugindir", dest='plugindir', type='string',
-            default=None, action='callback', callback=store_abspath,
-            metavar="DIR",
+    g.add_option("--designer-plugindir", dest='designerplugindir',
+            type='string', default=None, action='callback',
+            callback=store_abspath, metavar="DIR",
             help="install the Python plugin for Qt Designer in DIR "
                     "[default: QT_INSTALL_PLUGINS/designer]")
     g.add_option("--no-sip-files", action="store_false", default=True,
@@ -934,14 +941,19 @@ def check_modules(target_config, verbose):
             'new QAudioDeviceInfo()')
     check_module(target_config, verbose, 'QtNetwork', 'qhostaddress.h',
             'new QHostAddress()')
-    check_module(target_config, verbose, 'QtDeclarative', 'qdeclarativeview.h',
-            'new QDeclarativeView()')
+
+    if target_config.qt_version < 0x050000 or not target_config.no_deprecated:
+        check_module(target_config, verbose, 'QtDeclarative',
+                'qdeclarativeview.h', 'new QDeclarativeView()')
+        check_module(target_config, verbose, 'QtScript', 'qscriptengine.h',
+                'new QScriptEngine()')
+        check_module(target_config, verbose, 'QtScriptTools',
+                'qscriptenginedebugger.h', 'new QScriptEngineDebugger()')
+        check_module(target_config, verbose, 'QtXml', 'qdom.h',
+                'new QDomDocument()')
+
     check_module(target_config, verbose, 'QtOpenGL', 'qgl.h',
             'new QGLWidget()')
-    check_module(target_config, verbose, 'QtScript', 'qscriptengine.h',
-            'new QScriptEngine()')
-    check_module(target_config, verbose, 'QtScriptTools',
-            'qscriptenginedebugger.h', 'new QScriptEngineDebugger()')
     check_module(target_config, verbose, 'QtSql', 'qsqldatabase.h',
             'new QSqlDatabase()')
     check_module(target_config, verbose, 'QtSvg', 'qsvgwidget.h',
@@ -950,8 +962,6 @@ def check_modules(target_config, verbose):
             'QTest::qSleep(0)')
     check_module(target_config, verbose, 'QtWebKit', 'qwebpage.h',
             'new QWebPage()')
-    check_module(target_config, verbose, 'QtXml', 'qdom.h',
-            'new QDomDocument()')
     check_module(target_config, verbose, 'QtXmlPatterns', 'qxmlname.h',
             'new QXmlName()')
 
@@ -1135,12 +1145,9 @@ SUBDIRS = %s
         subdirs.append('_qt')
 
     # Generate pylupdate4 and pyrcc4.
-    if 'QtXml' in target_config.modules:
-        for tool in ('pylupdate', 'pyrcc'):
-            generate_application_makefile(target_config, verbose, tool)
-            subdirs.append(tool)
-    else:
-        inform("pylupdate4 and pyrcc4 will not be built because the Qt XML module is missing.")
+    for tool in ('pylupdate', 'pyrcc'):
+        generate_application_makefile(target_config, verbose, tool)
+        subdirs.append(tool)
 
     # Generate the pyuic4 wrapper.
     pyuic_wrapper = generate_pyuic4_wrapper(target_config)
@@ -1230,14 +1237,10 @@ INSTALLS += elementtree
 
     out_f.close()
 
-    # Generate the top-level makefile.
-    inform("Generating the top-level Makefile...")
-    run_qmake(target_config, verbose, toplevel_pro)
-
-    # Make the pyuic4 wrapper executable on platforms that support it.  If we
-    # did this before generating the top-level makefile qmake would try and
-    # strip it.  It doesn't actually matter if it does - but it's better to
-    # avoid confusing the user.
+    # Make the pyuic4 wrapper executable on platforms that support it.  This
+    # means that qmake will try and strip it after installing it resulting in
+    # an (ignored) error.  However if we did it after running qmake then (on
+    # Linux) the execute bits would be stripped on installation.
     if target_config.py_platform != 'win32':
         inform("Making the %s wrapper executable..." % pyuic_wrapper)
 
@@ -1246,6 +1249,10 @@ INSTALLS += elementtree
         mode |= (stat.S_IXUSR | stat.S_IXGRP | stat.S_IXOTH)
         os.chmod(pyuic_wrapper, mode)
 
+    # Generate the top-level makefile.
+    inform("Generating the top-level Makefile...")
+    run_qmake(target_config, verbose, toplevel_pro)
+
 
 def generate_designer_plugin_makefile(target_config, verbose):
     """ Generate the makefile for the Qt Designer plugin.  target_config is the
@@ -2415,10 +2422,6 @@ def check_qt(target_config):
     """ Check the Qt installation.  target_config is the target configuration.
     """
 
-    # Check the Qt version number.
-    if target_config.qt_version < 0x040100:
-        error("PyQt4 requires Qt v4.1.0 or later.")
-
     # Starting with v4.7, Qt (when built with MinGW) assumes that stack frames
     # are 16 byte aligned because it uses SSE.  However the Python Windows
     # installers are built with 4 byte aligned stack frames.  We therefore need
